@@ -33,11 +33,6 @@ use Data::Dumper;
 use Perl6::Pod::FormattingCode;
 use base 'Perl6::Pod::FormattingCode';
 
-sub start {
-    my $self = shift;
-    $self->delete_element->skip_content;
-}
-
 1;
 __END__
 
@@ -53,7 +48,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Zahatski Aliaksandr
+Copyright (C) 2009-2012 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
