@@ -97,9 +97,9 @@ sub parse_URI {
                              \s*$//x) {
         $attr->{rules} = $1
     }
-    
     my ( $scheme, $address, $section ) =
-      $lcontent =~ /\s*(\w+)\s*\:([^\#]*)(?:\#(.*))?/;
+    # Pod::Insertion::Name or http://www.com/d.pod(head1 :todo, para)
+      $lcontent =~ /\s*(\w+)\s*\:(?!\:)([^\#]*)(?:\#(.*))?/;
     #set default scheme
     unless ($scheme) {
         $scheme = 'file';
@@ -107,7 +107,7 @@ sub parse_URI {
     }
     $attr->{scheme} = $scheme;
     $address = '' unless defined $address;
-    $attr->{is_external} = $address =~ s/^\/\///;
+    $attr->{is_external} = $address =~ s/^\/\/// || $scheme =~ /mailto|skype/;
 
     #clean whitespaces
     $address =~ s/^\s+//;
