@@ -59,6 +59,7 @@ use Perl6::Pod::Writer;
 
 use Perl6::Pod::To::DocBook;
 use Perl6::Pod::To::XHTML;
+use Perl6::Pod::To::Latex;
 use XML::Flow;
 
 sub parse_to_docbook {
@@ -77,6 +78,19 @@ sub parse_to_docbook {
 }
 
 
+sub parse_to_latex {
+    shift if ref($_[0]);
+    my ( $text) = @_;
+    my $out    = '';
+    open( my $fd, ">", \$out );
+    my $renderer = new Perl6::Pod::To::Latex::
+      writer  => new Perl6::Pod::Writer::Latex( out => $fd, escape=>'latex' ),
+      out_put => \$out,
+      header => 0;
+    $renderer->parse( \$text, default_pod=>1 );
+    return wantarray ? (  $out, $renderer  ) : $out;
+}
+
 sub parse_to_xhtml {
     shift if ref($_[0]);
     my ( $text) = @_;
