@@ -13,26 +13,23 @@ use Data::Dumper;
 use Perl6::Pod::To::XHTML;
 use base 'TBase';
 
-sub t01_as_xml : Test {
-    my $t = shift;
-    my $x = $t->parse_to_xml( <<T);
-=para
-Text  E<lt>
-T
-    $t->is_deeply_xml( $x,
-q#<para pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'>Text <E pod:type='code'>lt</E></para>#
-    );
-}
 
 sub t01_as_xhtml : Test {
     my $t= shift;
     my $x = $t->parse_to_xhtml( <<T);
 =para
-Text  E<lt> E<gt> E<nbsp> E<laquo> 
+Text  E<lt> E<gt> E<nbsp> E<laquo> E<lt;gt>
 T
     ok $x =~ /&laquo;/;
-#    $t->is_deeply_xml( $x,
-# q#<xhtml xmlns='http://www.w3.org/1999/xhtml'><p>Text  &lt; &gt; &nbsp; &laquo; </p></xhtml># );
+}
+
+sub t03_as_xhtml : Test {
+    my $t= shift;
+    my $x = $t->parse_to_xhtml( <<T);
+=para
+sd E< lt ; LEFT DOUBLE ANGLE BRACKET >
+T
+    ok $x =~ /&lt;&#12298;/;
 }
 1;
 
